"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("@angular/common/http");
require("rxjs/add/operator/do");
require("rxjs/add/observable/throw");
require("rxjs/add/operator/map");
require("rxjs/add/operator/catch");
var BaseApi = /** @class */ (function () {
    function BaseApi(http) {
        this.http = http;
        this._loading = false;
    }
    Object.defineProperty(BaseApi.prototype, "loading", {
        /** 是否正在加载中 */
        get: function () {
            return this._loading;
        },
        enumerable: true,
        configurable: true
    });
    BaseApi.parseParams = function (params) {
        var ret = new http_1.HttpParams();
        if (params) {
            for (var key in params) {
                if (params[key]) {
                    var _data = params[key];
                    ret = ret.set(key, _data);
                }
            }
        }
        return ret;
    };
    BaseApi.parseHeaders = function (headers) {
        var ret = new http_1.HttpHeaders();
        if (headers) {
            for (var key in headers) {
                if (headers[key]) {
                    var _data = headers[key];
                    ret = ret.set(key, _data);
                }
            }
        }
        return ret;
    };
    BaseApi.prototype.begin = function () {
        this._loading = true;
    };
    BaseApi.prototype.end = function () {
        this._loading = false;
    };
    BaseApi.prototype.get = function (url, params, headers) {
        var _this = this;
        this.begin();
        return this.http
            .get(url, {
            headers: BaseApi.parseHeaders(headers),
            params: BaseApi.parseParams(params)
        })
            .do(function () { return _this.end(); });
    };
    BaseApi.prototype.post = function (url, body, params, headers) {
        var _this = this;
        this.begin();
        return this.http
            .post(url, body || null, {
            headers: BaseApi.parseHeaders(headers),
            params: BaseApi.parseParams(params)
        })
            .do(function () { return _this.end(); });
    };
    BaseApi.prototype.put = function (url, body, params, headers) {
        var _this = this;
        this.begin();
        return this.http
            .put(url, body || null, {
            headers: BaseApi.parseHeaders(headers),
            params: BaseApi.parseParams(params)
        })
            .do(function () { return _this.end(); });
    };
    BaseApi.prototype.delete = function (url, params, headers) {
        var _this = this;
        this.begin();
        return this.http
            .delete(url, {
            headers: BaseApi.parseHeaders(headers),
            params: BaseApi.parseParams(params)
        })
            .do(function () { return _this.end(); });
    };
    BaseApi.prototype.down = function (url, body) {
        var _this = this;
        this.begin();
        return this.http.post(url, body || null, {
            responseType: 'blob'
        })
            .do(function () { return _this.end(); });
    };
    BaseApi.prototype.downLoad = function (url, type, body, fileName) {
        return this.down(url, body).map(function (r) {
            var blob = new Blob([r], { type: type });
            var objectUrl = URL.createObjectURL(blob);
            var a = document.createElement('a');
            document.body.appendChild(a);
            a.setAttribute('style', 'display:none');
            a.setAttribute('href', objectUrl);
            if (fileName) {
                a.setAttribute('download', fileName);
            }
            else {
                a.setAttribute('target', '_blank');
            }
            a.click();
            URL.revokeObjectURL(objectUrl);
            return true;
        });
    };
    /**
     *  下载excel表格
     * @param {string} url
     * @param body
     * @param {string} fileName
     * @returns {Observable<boolean>}
     */
    BaseApi.prototype.downLoadXlsx = function (url, body, fileName) {
        return this.downLoad(url, 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet', body, fileName);
    };
    /**
     *  下载pdf， 如果不传入文件名会再浏览器中打开 实现打印功能
     *  传入文件名会直接下载
     * @param {string} url
     * @param body
     * @param {string} fileName
     * @returns {Observable<boolean>}
     */
    BaseApi.prototype.downLoadPdf = function (url, body, fileName) {
        return this.downLoad(url, 'application/pdf', body, fileName);
    };
    BaseApi.prototype.abpGet = function (url, params) {
        return this.get(url, params).map(function (r) {
            return BaseApi.process(r);
        });
    };
    BaseApi.prototype.abpPost = function (url, body, params) {
        return this.post(url, body, params).map(function (r) {
            return BaseApi.process(r);
        });
    };
    BaseApi.process = function (r) {
        var data = r;
        if (data.success) {
            return data.result;
        }
        else {
            console.error(data.error);
            throw data.error;
        }
    };
    return BaseApi;
}());
exports.BaseApi = BaseApi;
// 后台返回的结构体
var Result = /** @class */ (function () {
    function Result() {
        this.success = false;
    }
    return Result;
}());
exports.Result = Result;
